@@ -22,10 +22,11 @@ app.add_typer(list_app, name="list")
 
 MAX_LOGS = 10
 
+
 @list_app.command(name="logs")
 def list_logs(limit: int = MAX_LOGS):
     """Command to get all logs.
-    
+
     Args:
         limit: Maximum number of logs to return (default: `MAX_LOGS`)
     """
@@ -36,12 +37,14 @@ def list_logs(limit: int = MAX_LOGS):
         if len(response) > MAX_LOGS:  # Always show max 10 in CLI
             console.print(response[:MAX_LOGS])
             remaining = len(response) - MAX_LOGS
-            console.print(f"[yellow]\n... {remaining} more logs available. Use --limit <number> or the SDK to view more.[/yellow]")
+            console.print(
+                f"[yellow]\n... {remaining} more logs available. Use --limit <number> or the SDK to view more.[/yellow]"
+            )
         else:
             console.print(response)
     except QuotientAIError as e:
         raise
 
 
-if __name__ == "__main__": # pragma: no cover
+if __name__ == "__main__":  # pragma: no cover
     typer.run(app)
