@@ -1,11 +1,13 @@
 from quotientai.resources.auth import AuthResource
 from quotientai.resources.logs import LogsResource
 from quotientai.resources.logs import AsyncLogsResource
+from quotientai.resources.tracing import TracesResource
 from quotientai.tracing.core import TracingResource
 
 __all__ = [
     "AuthResource",
     "LogsResource",
     "AsyncLogsResource",
+    "TracesResource",
     "TracingResource",
 ]
