@@ -7,7 +7,7 @@ import enum
 import uuid
 
 from collections import deque
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from datetime import datetime, timezone
 from threading import Thread, Event
 from typing import Any, Dict, List, Optional, Union
@@ -48,12 +48,12 @@ class Log:
     hallucination_detection: bool
     inconsistency_detection: bool
     user_query: str
-    model_output: str
-    documents: Optional[List[Union[str, LogDocument]]]
-    message_history: Optional[List[Dict[str, Any]]]
-    instructions: Optional[List[str]]
-    tags: Dict[str, Any]
-    created_at: datetime
+    model_output: Optional[str] = None
+    documents: Optional[List[Union[str, LogDocument]]] = field(default_factory=list)
+    message_history: Optional[List[Dict[str, Any]]] = field(default_factory=list)
+    instructions: Optional[List[str]] = field(default_factory=list)
+    tags: Dict[str, Any] = field(default_factory=dict)
+    created_at: datetime = field(default_factory=lambda: datetime.now(timezone.utc))
     status: Optional[LogStatus] = None
     updated_at: Optional[datetime] = None
     has_hallucination: Optional[bool] = None
@@ -255,6 +255,33 @@ class LogsResource:
 
         try:
             response = self._client._get("/logs", params=params)
+            if response is None:
+                logger.error(
+                    f"Failed to retrieve logs from API. The server returned no response. Please check your connection and try again."
+                )
+                return []
+            
+            if response.get("logs") is None:
+                time_range = ""
+                if start_date and end_date:
+                    time_range = f" from {start_date.strftime('%Y-%m-%d')} to {end_date.strftime('%Y-%m-%d')}"
+                elif start_date:
+                    time_range = f" from {start_date.strftime('%Y-%m-%d')} onwards"
+                elif end_date:
+                    time_range = f" until {end_date.strftime('%Y-%m-%d')}"
+                
+                filters = []
+                if app_name:
+                    filters.append(f"app_name '{app_name}'")
+                if environment:
+                    filters.append(f"environment '{environment}'")
+                
+                filter_text = f" for {', '.join(filters)}" if filters else ""
+                logger.error(
+                    f"No logs found{filter_text}{time_range}. Please check your query parameters or try again in 30 seconds."
+                )
+                return []
+
             data = response["logs"]
 
             logs = []
@@ -422,11 +449,33 @@ class AsyncLogsResource:
 
         try:
             response = await self._client._get("/logs", params=params)
-            if response is None or response["logs"] is None:
+            if response is None:
                 logger.error(
-                    f"No logs found. Please check your query parameters and try again."
+                    f"Failed to retrieve logs from API. The server returned no response. Please check your connection and try again."
                 )
                 return []
+            
+            if response.get("logs") is None:
+                time_range = ""
+                if start_date and end_date:
+                    time_range = f" from {start_date.strftime('%Y-%m-%d')} to {end_date.strftime('%Y-%m-%d')}"
+                elif start_date:
+                    time_range = f" from {start_date.strftime('%Y-%m-%d')} onwards"
+                elif end_date:
+                    time_range = f" until {end_date.strftime('%Y-%m-%d')}"
+                
+                filters = []
+                if app_name:
+                    filters.append(f"app_name '{app_name}'")
+                if environment:
+                    filters.append(f"environment '{environment}'")
+                
+                filter_text = f" for {', '.join(filters)}" if filters else ""
+                logger.error(
+                    f"No logs found{filter_text}{time_range}. Please check your query parameters or try again in 30 seconds."
+                )
+                return []
+
             data = response["logs"]
 
             logs = []
